"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PostgresqlHostConfig13(google.protobuf.message.Message):
    """Options and structure of `PostgresqlConfig` reflects PostgreSQL configuration file
    parameters which detailed description is available in
    [PostgreSQL documentation](https://www.postgresql.org/docs/11/runtime-config.html).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BackslashQuote:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BackslashQuoteEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._BackslashQuote.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlHostConfig13._BackslashQuote.ValueType  # 0
        BACKSLASH_QUOTE: PostgresqlHostConfig13._BackslashQuote.ValueType  # 1
        """Quotation mark can be represented as \\' (same as on)."""
        BACKSLASH_QUOTE_ON: PostgresqlHostConfig13._BackslashQuote.ValueType  # 2
        """Quotation mark can be represented as \\'."""
        BACKSLASH_QUOTE_OFF: PostgresqlHostConfig13._BackslashQuote.ValueType  # 3
        """Quotation mark can only be represented using the standard SQL syntax ''."""
        BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlHostConfig13._BackslashQuote.ValueType  # 4
        """Representing a quotation mark as \\' is only permitted for client encodings where \\ is not used for multibyte characters."""

    class BackslashQuote(_BackslashQuote, metaclass=_BackslashQuoteEnumTypeWrapper): ...
    BACKSLASH_QUOTE_UNSPECIFIED: PostgresqlHostConfig13.BackslashQuote.ValueType  # 0
    BACKSLASH_QUOTE: PostgresqlHostConfig13.BackslashQuote.ValueType  # 1
    """Quotation mark can be represented as \\' (same as on)."""
    BACKSLASH_QUOTE_ON: PostgresqlHostConfig13.BackslashQuote.ValueType  # 2
    """Quotation mark can be represented as \\'."""
    BACKSLASH_QUOTE_OFF: PostgresqlHostConfig13.BackslashQuote.ValueType  # 3
    """Quotation mark can only be represented using the standard SQL syntax ''."""
    BACKSLASH_QUOTE_SAFE_ENCODING: PostgresqlHostConfig13.BackslashQuote.ValueType  # 4
    """Representing a quotation mark as \\' is only permitted for client encodings where \\ is not used for multibyte characters."""

    class _ByteaOutput:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ByteaOutputEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._ByteaOutput.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BYTEA_OUTPUT_UNSPECIFIED: PostgresqlHostConfig13._ByteaOutput.ValueType  # 0
        BYTEA_OUTPUT_HEX: PostgresqlHostConfig13._ByteaOutput.ValueType  # 1
        """Each byte is represented by two hexadecimal characters, e.g., 'SELECT '\\xDEADBEEF';'."""
        BYTEA_OUTPUT_ESCAPED: PostgresqlHostConfig13._ByteaOutput.ValueType  # 2
        """Standard PostgreSQL format with ASCII characters only."""

    class ByteaOutput(_ByteaOutput, metaclass=_ByteaOutputEnumTypeWrapper): ...
    BYTEA_OUTPUT_UNSPECIFIED: PostgresqlHostConfig13.ByteaOutput.ValueType  # 0
    BYTEA_OUTPUT_HEX: PostgresqlHostConfig13.ByteaOutput.ValueType  # 1
    """Each byte is represented by two hexadecimal characters, e.g., 'SELECT '\\xDEADBEEF';'."""
    BYTEA_OUTPUT_ESCAPED: PostgresqlHostConfig13.ByteaOutput.ValueType  # 2
    """Standard PostgreSQL format with ASCII characters only."""

    class _ConstraintExclusion:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConstraintExclusionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._ConstraintExclusion.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlHostConfig13._ConstraintExclusion.ValueType  # 0
        CONSTRAINT_EXCLUSION_ON: PostgresqlHostConfig13._ConstraintExclusion.ValueType  # 1
        """Enable planner's use of constraints for all tables."""
        CONSTRAINT_EXCLUSION_OFF: PostgresqlHostConfig13._ConstraintExclusion.ValueType  # 2
        """Disable planner's use of constraints for all tables"""
        CONSTRAINT_EXCLUSION_PARTITION: PostgresqlHostConfig13._ConstraintExclusion.ValueType  # 3
        """Only use constraints for child tables and UNION ALL clauses."""

    class ConstraintExclusion(_ConstraintExclusion, metaclass=_ConstraintExclusionEnumTypeWrapper): ...
    CONSTRAINT_EXCLUSION_UNSPECIFIED: PostgresqlHostConfig13.ConstraintExclusion.ValueType  # 0
    CONSTRAINT_EXCLUSION_ON: PostgresqlHostConfig13.ConstraintExclusion.ValueType  # 1
    """Enable planner's use of constraints for all tables."""
    CONSTRAINT_EXCLUSION_OFF: PostgresqlHostConfig13.ConstraintExclusion.ValueType  # 2
    """Disable planner's use of constraints for all tables"""
    CONSTRAINT_EXCLUSION_PARTITION: PostgresqlHostConfig13.ConstraintExclusion.ValueType  # 3
    """Only use constraints for child tables and UNION ALL clauses."""

    class _ForceParallelMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ForceParallelModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._ForceParallelMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlHostConfig13._ForceParallelMode.ValueType  # 0
        FORCE_PARALLEL_MODE_ON: PostgresqlHostConfig13._ForceParallelMode.ValueType  # 1
        """Force parallel mode for all queries that can be executed safely in parallel."""
        FORCE_PARALLEL_MODE_OFF: PostgresqlHostConfig13._ForceParallelMode.ValueType  # 2
        """Enable parallel mode only if it is expected to increase performance."""
        FORCE_PARALLEL_MODE_REGRESS: PostgresqlHostConfig13._ForceParallelMode.ValueType  # 3
        """Equivalent to on, but generates output identical to the off state."""

    class ForceParallelMode(_ForceParallelMode, metaclass=_ForceParallelModeEnumTypeWrapper): ...
    FORCE_PARALLEL_MODE_UNSPECIFIED: PostgresqlHostConfig13.ForceParallelMode.ValueType  # 0
    FORCE_PARALLEL_MODE_ON: PostgresqlHostConfig13.ForceParallelMode.ValueType  # 1
    """Force parallel mode for all queries that can be executed safely in parallel."""
    FORCE_PARALLEL_MODE_OFF: PostgresqlHostConfig13.ForceParallelMode.ValueType  # 2
    """Enable parallel mode only if it is expected to increase performance."""
    FORCE_PARALLEL_MODE_REGRESS: PostgresqlHostConfig13.ForceParallelMode.ValueType  # 3
    """Equivalent to on, but generates output identical to the off state."""

    class _LogErrorVerbosity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogErrorVerbosityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._LogErrorVerbosity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlHostConfig13._LogErrorVerbosity.ValueType  # 0
        LOG_ERROR_VERBOSITY_TERSE: PostgresqlHostConfig13._LogErrorVerbosity.ValueType  # 1
        """DETAIL, HINT, QUERY, and CONTEXT fields are excluded from the error message."""
        LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlHostConfig13._LogErrorVerbosity.ValueType  # 2
        """Default."""
        LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlHostConfig13._LogErrorVerbosity.ValueType  # 3
        """Error message includes the SQLSTATE error code, source filename, function name, and the line number where the error occurred."""

    class LogErrorVerbosity(_LogErrorVerbosity, metaclass=_LogErrorVerbosityEnumTypeWrapper): ...
    LOG_ERROR_VERBOSITY_UNSPECIFIED: PostgresqlHostConfig13.LogErrorVerbosity.ValueType  # 0
    LOG_ERROR_VERBOSITY_TERSE: PostgresqlHostConfig13.LogErrorVerbosity.ValueType  # 1
    """DETAIL, HINT, QUERY, and CONTEXT fields are excluded from the error message."""
    LOG_ERROR_VERBOSITY_DEFAULT: PostgresqlHostConfig13.LogErrorVerbosity.ValueType  # 2
    """Default."""
    LOG_ERROR_VERBOSITY_VERBOSE: PostgresqlHostConfig13.LogErrorVerbosity.ValueType  # 3
    """Error message includes the SQLSTATE error code, source filename, function name, and the line number where the error occurred."""

    class _LogLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._LogLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_LEVEL_UNSPECIFIED: PostgresqlHostConfig13._LogLevel.ValueType  # 0
        LOG_LEVEL_DEBUG5: PostgresqlHostConfig13._LogLevel.ValueType  # 1
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG4: PostgresqlHostConfig13._LogLevel.ValueType  # 2
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG3: PostgresqlHostConfig13._LogLevel.ValueType  # 3
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG2: PostgresqlHostConfig13._LogLevel.ValueType  # 4
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_DEBUG1: PostgresqlHostConfig13._LogLevel.ValueType  # 5
        """Provides successively-more-detailed information for use by developers."""
        LOG_LEVEL_LOG: PostgresqlHostConfig13._LogLevel.ValueType  # 6
        """Reports information of interest to administrators, e.g., checkpoint activity."""
        LOG_LEVEL_NOTICE: PostgresqlHostConfig13._LogLevel.ValueType  # 7
        """Provides information that might be helpful to users, e.g., notice of truncation of long identifiers."""
        LOG_LEVEL_WARNING: PostgresqlHostConfig13._LogLevel.ValueType  # 8
        """Provides warnings of likely problems, e.g., COMMIT outside a transaction block."""
        LOG_LEVEL_ERROR: PostgresqlHostConfig13._LogLevel.ValueType  # 9
        """Reports an error that caused the current command to abort."""
        LOG_LEVEL_FATAL: PostgresqlHostConfig13._LogLevel.ValueType  # 10
        """Reports an error that caused the current session to abort."""
        LOG_LEVEL_PANIC: PostgresqlHostConfig13._LogLevel.ValueType  # 11
        """Reports an error that caused all database sessions to abort."""

    class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper): ...
    LOG_LEVEL_UNSPECIFIED: PostgresqlHostConfig13.LogLevel.ValueType  # 0
    LOG_LEVEL_DEBUG5: PostgresqlHostConfig13.LogLevel.ValueType  # 1
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG4: PostgresqlHostConfig13.LogLevel.ValueType  # 2
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG3: PostgresqlHostConfig13.LogLevel.ValueType  # 3
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG2: PostgresqlHostConfig13.LogLevel.ValueType  # 4
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_DEBUG1: PostgresqlHostConfig13.LogLevel.ValueType  # 5
    """Provides successively-more-detailed information for use by developers."""
    LOG_LEVEL_LOG: PostgresqlHostConfig13.LogLevel.ValueType  # 6
    """Reports information of interest to administrators, e.g., checkpoint activity."""
    LOG_LEVEL_NOTICE: PostgresqlHostConfig13.LogLevel.ValueType  # 7
    """Provides information that might be helpful to users, e.g., notice of truncation of long identifiers."""
    LOG_LEVEL_WARNING: PostgresqlHostConfig13.LogLevel.ValueType  # 8
    """Provides warnings of likely problems, e.g., COMMIT outside a transaction block."""
    LOG_LEVEL_ERROR: PostgresqlHostConfig13.LogLevel.ValueType  # 9
    """Reports an error that caused the current command to abort."""
    LOG_LEVEL_FATAL: PostgresqlHostConfig13.LogLevel.ValueType  # 10
    """Reports an error that caused the current session to abort."""
    LOG_LEVEL_PANIC: PostgresqlHostConfig13.LogLevel.ValueType  # 11
    """Reports an error that caused all database sessions to abort."""

    class _LogStatement:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._LogStatement.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOG_STATEMENT_UNSPECIFIED: PostgresqlHostConfig13._LogStatement.ValueType  # 0
        LOG_STATEMENT_NONE: PostgresqlHostConfig13._LogStatement.ValueType  # 1
        """The filter is disabled, no SQL statements are logged."""
        LOG_STATEMENT_DDL: PostgresqlHostConfig13._LogStatement.ValueType  # 2
        """System logs DDL statements, e.g., CREATE, ALTER, DROP etc."""
        LOG_STATEMENT_MOD: PostgresqlHostConfig13._LogStatement.ValueType  # 3
        """System logs ddl-statements along with data modification commands, e.g., INSERT, UPDATE, etc."""
        LOG_STATEMENT_ALL: PostgresqlHostConfig13._LogStatement.ValueType  # 4
        """System logs all SQL statements."""

    class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...
    LOG_STATEMENT_UNSPECIFIED: PostgresqlHostConfig13.LogStatement.ValueType  # 0
    LOG_STATEMENT_NONE: PostgresqlHostConfig13.LogStatement.ValueType  # 1
    """The filter is disabled, no SQL statements are logged."""
    LOG_STATEMENT_DDL: PostgresqlHostConfig13.LogStatement.ValueType  # 2
    """System logs DDL statements, e.g., CREATE, ALTER, DROP etc."""
    LOG_STATEMENT_MOD: PostgresqlHostConfig13.LogStatement.ValueType  # 3
    """System logs ddl-statements along with data modification commands, e.g., INSERT, UPDATE, etc."""
    LOG_STATEMENT_ALL: PostgresqlHostConfig13.LogStatement.ValueType  # 4
    """System logs all SQL statements."""

    class _TransactionIsolation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransactionIsolationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._TransactionIsolation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlHostConfig13._TransactionIsolation.ValueType  # 0
        TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlHostConfig13._TransactionIsolation.ValueType  # 1
        """This level behaves like `TRANSACTION_ISOLATION_READ_COMMITTED` in PostgreSQL."""
        TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlHostConfig13._TransactionIsolation.ValueType  # 2
        """On this level query sees only data committed before the query began."""
        TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlHostConfig13._TransactionIsolation.ValueType  # 3
        """On this level all subsequent queries in a transaction will see the same rows, that were read by the first `SELECT` or `INSERT` query in this transaction, unchanged (these rows are locked during the first query)."""
        TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlHostConfig13._TransactionIsolation.ValueType  # 4
        """This level provides the strictest transaction isolation.
        All queries in the current transaction see only the rows that were fixed prior to execution of the first `SELECT` or `INSERT` query in this transaction.
        If read and write operations in a concurrent set of serializable transactions overlap and this may cause an inconsistency that is not possible during the serial transaction execution, then one of the transaction will be rolled back, triggering a serialization failure.
        """

    class TransactionIsolation(_TransactionIsolation, metaclass=_TransactionIsolationEnumTypeWrapper): ...
    TRANSACTION_ISOLATION_UNSPECIFIED: PostgresqlHostConfig13.TransactionIsolation.ValueType  # 0
    TRANSACTION_ISOLATION_READ_UNCOMMITTED: PostgresqlHostConfig13.TransactionIsolation.ValueType  # 1
    """This level behaves like `TRANSACTION_ISOLATION_READ_COMMITTED` in PostgreSQL."""
    TRANSACTION_ISOLATION_READ_COMMITTED: PostgresqlHostConfig13.TransactionIsolation.ValueType  # 2
    """On this level query sees only data committed before the query began."""
    TRANSACTION_ISOLATION_REPEATABLE_READ: PostgresqlHostConfig13.TransactionIsolation.ValueType  # 3
    """On this level all subsequent queries in a transaction will see the same rows, that were read by the first `SELECT` or `INSERT` query in this transaction, unchanged (these rows are locked during the first query)."""
    TRANSACTION_ISOLATION_SERIALIZABLE: PostgresqlHostConfig13.TransactionIsolation.ValueType  # 4
    """This level provides the strictest transaction isolation.
    All queries in the current transaction see only the rows that were fixed prior to execution of the first `SELECT` or `INSERT` query in this transaction.
    If read and write operations in a concurrent set of serializable transactions overlap and this may cause an inconsistency that is not possible during the serial transaction execution, then one of the transaction will be rolled back, triggering a serialization failure.
    """

    class _XmlBinary:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlBinaryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._XmlBinary.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_BINARY_UNSPECIFIED: PostgresqlHostConfig13._XmlBinary.ValueType  # 0
        XML_BINARY_BASE64: PostgresqlHostConfig13._XmlBinary.ValueType  # 1
        """Base64 encoding."""
        XML_BINARY_HEX: PostgresqlHostConfig13._XmlBinary.ValueType  # 2
        """Hexadecimal encoding."""

    class XmlBinary(_XmlBinary, metaclass=_XmlBinaryEnumTypeWrapper): ...
    XML_BINARY_UNSPECIFIED: PostgresqlHostConfig13.XmlBinary.ValueType  # 0
    XML_BINARY_BASE64: PostgresqlHostConfig13.XmlBinary.ValueType  # 1
    """Base64 encoding."""
    XML_BINARY_HEX: PostgresqlHostConfig13.XmlBinary.ValueType  # 2
    """Hexadecimal encoding."""

    class _XmlOption:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _XmlOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostgresqlHostConfig13._XmlOption.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        XML_OPTION_UNSPECIFIED: PostgresqlHostConfig13._XmlOption.ValueType  # 0
        XML_OPTION_DOCUMENT: PostgresqlHostConfig13._XmlOption.ValueType  # 1
        """XML document."""
        XML_OPTION_CONTENT: PostgresqlHostConfig13._XmlOption.ValueType  # 2
        """XML fragment."""

    class XmlOption(_XmlOption, metaclass=_XmlOptionEnumTypeWrapper): ...
    XML_OPTION_UNSPECIFIED: PostgresqlHostConfig13.XmlOption.ValueType  # 0
    XML_OPTION_DOCUMENT: PostgresqlHostConfig13.XmlOption.ValueType  # 1
    """XML document."""
    XML_OPTION_CONTENT: PostgresqlHostConfig13.XmlOption.ValueType  # 2
    """XML fragment."""

    RECOVERY_MIN_APPLY_DELAY_FIELD_NUMBER: builtins.int
    SHARED_BUFFERS_FIELD_NUMBER: builtins.int
    TEMP_BUFFERS_FIELD_NUMBER: builtins.int
    WORK_MEM_FIELD_NUMBER: builtins.int
    TEMP_FILE_LIMIT_FIELD_NUMBER: builtins.int
    BACKEND_FLUSH_AFTER_FIELD_NUMBER: builtins.int
    OLD_SNAPSHOT_THRESHOLD_FIELD_NUMBER: builtins.int
    MAX_STANDBY_STREAMING_DELAY_FIELD_NUMBER: builtins.int
    CONSTRAINT_EXCLUSION_FIELD_NUMBER: builtins.int
    CURSOR_TUPLE_FRACTION_FIELD_NUMBER: builtins.int
    FROM_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    JOIN_COLLAPSE_LIMIT_FIELD_NUMBER: builtins.int
    FORCE_PARALLEL_MODE_FIELD_NUMBER: builtins.int
    CLIENT_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_MESSAGES_FIELD_NUMBER: builtins.int
    LOG_MIN_ERROR_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_MIN_DURATION_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_CHECKPOINTS_FIELD_NUMBER: builtins.int
    LOG_CONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DISCONNECTIONS_FIELD_NUMBER: builtins.int
    LOG_DURATION_FIELD_NUMBER: builtins.int
    LOG_ERROR_VERBOSITY_FIELD_NUMBER: builtins.int
    LOG_LOCK_WAITS_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    LOG_TEMP_FILES_FIELD_NUMBER: builtins.int
    SEARCH_PATH_FIELD_NUMBER: builtins.int
    ROW_SECURITY_FIELD_NUMBER: builtins.int
    DEFAULT_TRANSACTION_ISOLATION_FIELD_NUMBER: builtins.int
    STATEMENT_TIMEOUT_FIELD_NUMBER: builtins.int
    LOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_SESSION_TIMEOUT_FIELD_NUMBER: builtins.int
    BYTEA_OUTPUT_FIELD_NUMBER: builtins.int
    XMLBINARY_FIELD_NUMBER: builtins.int
    XMLOPTION_FIELD_NUMBER: builtins.int
    GIN_PENDING_LIST_LIMIT_FIELD_NUMBER: builtins.int
    DEADLOCK_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    MAX_PRED_LOCKS_PER_TRANSACTION_FIELD_NUMBER: builtins.int
    ARRAY_NULLS_FIELD_NUMBER: builtins.int
    BACKSLASH_QUOTE_FIELD_NUMBER: builtins.int
    DEFAULT_WITH_OIDS_FIELD_NUMBER: builtins.int
    ESCAPE_STRING_WARNING_FIELD_NUMBER: builtins.int
    LO_COMPAT_PRIVILEGES_FIELD_NUMBER: builtins.int
    OPERATOR_PRECEDENCE_WARNING_FIELD_NUMBER: builtins.int
    QUOTE_ALL_IDENTIFIERS_FIELD_NUMBER: builtins.int
    STANDARD_CONFORMING_STRINGS_FIELD_NUMBER: builtins.int
    SYNCHRONIZE_SEQSCANS_FIELD_NUMBER: builtins.int
    TRANSFORM_NULL_EQUALS_FIELD_NUMBER: builtins.int
    EXIT_ON_ERROR_FIELD_NUMBER: builtins.int
    SEQ_PAGE_COST_FIELD_NUMBER: builtins.int
    RANDOM_PAGE_COST_FIELD_NUMBER: builtins.int
    ENABLE_BITMAPSCAN_FIELD_NUMBER: builtins.int
    ENABLE_HASHAGG_FIELD_NUMBER: builtins.int
    ENABLE_HASHJOIN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXSCAN_FIELD_NUMBER: builtins.int
    ENABLE_INDEXONLYSCAN_FIELD_NUMBER: builtins.int
    ENABLE_MATERIAL_FIELD_NUMBER: builtins.int
    ENABLE_MERGEJOIN_FIELD_NUMBER: builtins.int
    ENABLE_NESTLOOP_FIELD_NUMBER: builtins.int
    ENABLE_SEQSCAN_FIELD_NUMBER: builtins.int
    ENABLE_SORT_FIELD_NUMBER: builtins.int
    ENABLE_TIDSCAN_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_FIELD_NUMBER: builtins.int
    MAX_PARALLEL_WORKERS_PER_GATHER_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    EFFECTIVE_IO_CONCURRENCY_FIELD_NUMBER: builtins.int
    EFFECTIVE_CACHE_SIZE_FIELD_NUMBER: builtins.int
    constraint_exclusion: global___PostgresqlHostConfig13.ConstraintExclusion.ValueType
    force_parallel_mode: global___PostgresqlHostConfig13.ForceParallelMode.ValueType
    client_min_messages: global___PostgresqlHostConfig13.LogLevel.ValueType
    log_min_messages: global___PostgresqlHostConfig13.LogLevel.ValueType
    log_min_error_statement: global___PostgresqlHostConfig13.LogLevel.ValueType
    log_error_verbosity: global___PostgresqlHostConfig13.LogErrorVerbosity.ValueType
    log_statement: global___PostgresqlHostConfig13.LogStatement.ValueType
    search_path: builtins.str
    default_transaction_isolation: global___PostgresqlHostConfig13.TransactionIsolation.ValueType
    bytea_output: global___PostgresqlHostConfig13.ByteaOutput.ValueType
    xmlbinary: global___PostgresqlHostConfig13.XmlBinary.ValueType
    xmloption: global___PostgresqlHostConfig13.XmlOption.ValueType
    backslash_quote: global___PostgresqlHostConfig13.BackslashQuote.ValueType
    timezone: builtins.str
    @property
    def recovery_min_apply_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def shared_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_buffers(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def work_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def temp_file_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def backend_flush_after(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def old_snapshot_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_standby_streaming_delay(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def cursor_tuple_fraction(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def from_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def join_collapse_limit(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def log_min_duration_statement(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def log_checkpoints(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_connections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_disconnections(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_duration(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_lock_waits(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def log_temp_files(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def row_security(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def statement_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def lock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def idle_in_transaction_session_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def gin_pending_list_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in bytes."""

    @property
    def deadlock_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """in milliseconds."""

    @property
    def max_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_pred_locks_per_transaction(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def array_nulls(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def default_with_oids(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def escape_string_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def lo_compat_privileges(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def operator_precedence_warning(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def quote_all_identifiers(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def standard_conforming_strings(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def synchronize_seqscans(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def transform_null_equals(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def exit_on_error(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def seq_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def random_page_cost(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def enable_bitmapscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashagg(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_hashjoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_indexonlyscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_material(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_mergejoin(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_nestloop(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_seqscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_sort(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def enable_tidscan(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_parallel_workers(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def max_parallel_workers_per_gather(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def effective_io_concurrency(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def effective_cache_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        recovery_min_apply_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        shared_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_buffers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        work_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temp_file_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        backend_flush_after: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        old_snapshot_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_standby_streaming_delay: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        constraint_exclusion: global___PostgresqlHostConfig13.ConstraintExclusion.ValueType = ...,
        cursor_tuple_fraction: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        from_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        join_collapse_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        force_parallel_mode: global___PostgresqlHostConfig13.ForceParallelMode.ValueType = ...,
        client_min_messages: global___PostgresqlHostConfig13.LogLevel.ValueType = ...,
        log_min_messages: global___PostgresqlHostConfig13.LogLevel.ValueType = ...,
        log_min_error_statement: global___PostgresqlHostConfig13.LogLevel.ValueType = ...,
        log_min_duration_statement: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_checkpoints: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_connections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_disconnections: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_duration: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_error_verbosity: global___PostgresqlHostConfig13.LogErrorVerbosity.ValueType = ...,
        log_lock_waits: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        log_statement: global___PostgresqlHostConfig13.LogStatement.ValueType = ...,
        log_temp_files: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        search_path: builtins.str = ...,
        row_security: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        default_transaction_isolation: global___PostgresqlHostConfig13.TransactionIsolation.ValueType = ...,
        statement_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        idle_in_transaction_session_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        bytea_output: global___PostgresqlHostConfig13.ByteaOutput.ValueType = ...,
        xmlbinary: global___PostgresqlHostConfig13.XmlBinary.ValueType = ...,
        xmloption: global___PostgresqlHostConfig13.XmlOption.ValueType = ...,
        gin_pending_list_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        deadlock_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_pred_locks_per_transaction: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        array_nulls: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backslash_quote: global___PostgresqlHostConfig13.BackslashQuote.ValueType = ...,
        default_with_oids: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        escape_string_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        lo_compat_privileges: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        operator_precedence_warning: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        quote_all_identifiers: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        standard_conforming_strings: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        synchronize_seqscans: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        transform_null_equals: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        exit_on_error: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        seq_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        random_page_cost: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        enable_bitmapscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashagg: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_hashjoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_indexonlyscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_material: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_mergejoin: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_nestloop: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_seqscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_sort: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_tidscan: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_parallel_workers: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_parallel_workers_per_gather: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        timezone: builtins.str = ...,
        effective_io_concurrency: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        effective_cache_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["array_nulls", b"array_nulls", "backend_flush_after", b"backend_flush_after", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "from_collapse_limit", b"from_collapse_limit", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_temp_files", b"log_temp_files", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_standby_streaming_delay", b"max_standby_streaming_delay", "old_snapshot_threshold", b"old_snapshot_threshold", "operator_precedence_warning", b"operator_precedence_warning", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "recovery_min_apply_delay", b"recovery_min_apply_delay", "row_security", b"row_security", "seq_page_cost", b"seq_page_cost", "shared_buffers", b"shared_buffers", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "transform_null_equals", b"transform_null_equals", "work_mem", b"work_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["array_nulls", b"array_nulls", "backend_flush_after", b"backend_flush_after", "backslash_quote", b"backslash_quote", "bytea_output", b"bytea_output", "client_min_messages", b"client_min_messages", "constraint_exclusion", b"constraint_exclusion", "cursor_tuple_fraction", b"cursor_tuple_fraction", "deadlock_timeout", b"deadlock_timeout", "default_transaction_isolation", b"default_transaction_isolation", "default_with_oids", b"default_with_oids", "effective_cache_size", b"effective_cache_size", "effective_io_concurrency", b"effective_io_concurrency", "enable_bitmapscan", b"enable_bitmapscan", "enable_hashagg", b"enable_hashagg", "enable_hashjoin", b"enable_hashjoin", "enable_indexonlyscan", b"enable_indexonlyscan", "enable_indexscan", b"enable_indexscan", "enable_material", b"enable_material", "enable_mergejoin", b"enable_mergejoin", "enable_nestloop", b"enable_nestloop", "enable_seqscan", b"enable_seqscan", "enable_sort", b"enable_sort", "enable_tidscan", b"enable_tidscan", "escape_string_warning", b"escape_string_warning", "exit_on_error", b"exit_on_error", "force_parallel_mode", b"force_parallel_mode", "from_collapse_limit", b"from_collapse_limit", "gin_pending_list_limit", b"gin_pending_list_limit", "idle_in_transaction_session_timeout", b"idle_in_transaction_session_timeout", "join_collapse_limit", b"join_collapse_limit", "lo_compat_privileges", b"lo_compat_privileges", "lock_timeout", b"lock_timeout", "log_checkpoints", b"log_checkpoints", "log_connections", b"log_connections", "log_disconnections", b"log_disconnections", "log_duration", b"log_duration", "log_error_verbosity", b"log_error_verbosity", "log_lock_waits", b"log_lock_waits", "log_min_duration_statement", b"log_min_duration_statement", "log_min_error_statement", b"log_min_error_statement", "log_min_messages", b"log_min_messages", "log_statement", b"log_statement", "log_temp_files", b"log_temp_files", "max_locks_per_transaction", b"max_locks_per_transaction", "max_parallel_workers", b"max_parallel_workers", "max_parallel_workers_per_gather", b"max_parallel_workers_per_gather", "max_pred_locks_per_transaction", b"max_pred_locks_per_transaction", "max_standby_streaming_delay", b"max_standby_streaming_delay", "old_snapshot_threshold", b"old_snapshot_threshold", "operator_precedence_warning", b"operator_precedence_warning", "quote_all_identifiers", b"quote_all_identifiers", "random_page_cost", b"random_page_cost", "recovery_min_apply_delay", b"recovery_min_apply_delay", "row_security", b"row_security", "search_path", b"search_path", "seq_page_cost", b"seq_page_cost", "shared_buffers", b"shared_buffers", "standard_conforming_strings", b"standard_conforming_strings", "statement_timeout", b"statement_timeout", "synchronize_seqscans", b"synchronize_seqscans", "temp_buffers", b"temp_buffers", "temp_file_limit", b"temp_file_limit", "timezone", b"timezone", "transform_null_equals", b"transform_null_equals", "work_mem", b"work_mem", "xmlbinary", b"xmlbinary", "xmloption", b"xmloption"]) -> None: ...

global___PostgresqlHostConfig13 = PostgresqlHostConfig13



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudregistry/v1/lifecycle_policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudregistry/v1/lifecycle_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/cloudregistry/v1/lifecycle_policy.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe0\x02\n\x0fLifecyclePolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12;\n\x05rules\x18\x04 \x03(\x0b\x32,.yandex.cloud.cloudregistry.v1.LifecycleRule\x12\x42\n\x05state\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.cloudregistry.v1.LifecyclePolicyState\x12\x13\n\x0bregistry_id\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\t \x01(\t\x12\x13\n\x0bmodified_by\x18\n \x01(\t\"\xc6\x03\n\rLifecycleRule\x12\x13\n\x0bpath_prefix\x18\x01 \x01(\t\x12L\n\x0bkeep_by_age\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.cloudregistry.v1.KeepByAgeLifecycleRuleH\x00\x12T\n\x0fkeep_by_version\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.cloudregistry.v1.KeepByVersionLifecycleRuleH\x00\x12\x44\n\x06\x64\x65lete\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.cloudregistry.v1.DeleteLifecycleRuleH\x00\x12\x46\n\x0e\x64ocker_filters\x18\x05 \x01(\x0b\x32,.yandex.cloud.cloudregistry.v1.DockerFiltersH\x01\x12\x44\n\rmaven_filters\x18\x06 \x01(\x0b\x32+.yandex.cloud.cloudregistry.v1.MavenFiltersH\x01\x12\x16\n\x0eversion_regexp\x18\x07 \x01(\tB\x06\n\x04kindB\x08\n\x06\x66ilter\"\xb2\x01\n\rDockerFilters\x12J\n\ntag_status\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.cloudregistry.v1.DockerFilters.TagStatus\"U\n\tTagStatus\x12\x1a\n\x16TAG_STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eTAG_STATUS_ANY\x10\x01\x12\n\n\x06TAGGED\x10\x02\x12\x0c\n\x08UNTAGGED\x10\x03\"\xbb\x01\n\x0cMavenFilters\x12M\n\x0cversion_type\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.cloudregistry.v1.MavenFilters.VersionType\"\\\n\x0bVersionType\x12\x1c\n\x18VERSION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10VERSION_TYPE_ANY\x10\x01\x12\x0b\n\x07RELEASE\x10\x02\x12\x0c\n\x08SNAPSHOT\x10\x03\"9\n\x1aKeepByVersionLifecycleRule\x12\x1b\n\x13keep_versions_count\x18\x01 \x01(\x03\"3\n\x16KeepByAgeLifecycleRule\x12\x19\n\x11younger_than_days\x18\x01 \x01(\x03\"\x89\x02\n\x13\x44\x65leteLifecycleRule\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.cloudregistry.v1.DeleteLifecycleRuleKind\x12\x1c\n\x14\x63ooldown_period_days\x18\x02 \x01(\x03\x12\x19\n\x0folder_than_days\x18\x03 \x01(\x03H\x00\x12T\n\x11version_condition\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.cloudregistry.v1.DeleteByVersionConditionH\x00\x12\x10\n\x06\x61lways\x18\x05 \x01(\x08H\x00\x42\x0b\n\tcondition\"?\n\x18\x44\x65leteByVersionCondition\x12#\n\x1bversions_count_greater_than\x18\x01 \x01(\x03*g\n\x17\x44\x65leteLifecycleRuleKind\x12*\n&DELETE_LIFECYCLE_RULE_KIND_UNSPECIFIED\x10\x00\x12\x0f\n\x0bHARD_DELETE\x10\x01\x12\x0f\n\x0bSOFT_DELETE\x10\x02*Y\n\x14LifecyclePolicyState\x12&\n\"LIFECYCLE_POLICY_STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x42t\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _globals['_DELETELIFECYCLERULEKIND']._serialized_start=1748
  _globals['_DELETELIFECYCLERULEKIND']._serialized_end=1851
  _globals['_LIFECYCLEPOLICYSTATE']._serialized_start=1853
  _globals['_LIFECYCLEPOLICYSTATE']._serialized_end=1942
  _globals['_LIFECYCLEPOLICY']._serialized_start=121
  _globals['_LIFECYCLEPOLICY']._serialized_end=473
  _globals['_LIFECYCLERULE']._serialized_start=476
  _globals['_LIFECYCLERULE']._serialized_end=930
  _globals['_DOCKERFILTERS']._serialized_start=933
  _globals['_DOCKERFILTERS']._serialized_end=1111
  _globals['_DOCKERFILTERS_TAGSTATUS']._serialized_start=1026
  _globals['_DOCKERFILTERS_TAGSTATUS']._serialized_end=1111
  _globals['_MAVENFILTERS']._serialized_start=1114
  _globals['_MAVENFILTERS']._serialized_end=1301
  _globals['_MAVENFILTERS_VERSIONTYPE']._serialized_start=1209
  _globals['_MAVENFILTERS_VERSIONTYPE']._serialized_end=1301
  _globals['_KEEPBYVERSIONLIFECYCLERULE']._serialized_start=1303
  _globals['_KEEPBYVERSIONLIFECYCLERULE']._serialized_end=1360
  _globals['_KEEPBYAGELIFECYCLERULE']._serialized_start=1362
  _globals['_KEEPBYAGELIFECYCLERULE']._serialized_end=1413
  _globals['_DELETELIFECYCLERULE']._serialized_start=1416
  _globals['_DELETELIFECYCLERULE']._serialized_end=1681
  _globals['_DELETEBYVERSIONCONDITION']._serialized_start=1683
  _globals['_DELETEBYVERSIONCONDITION']._serialized_end=1746
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to create a lifecycle policy in."""
    name: builtins.str
    """Name of the lifecycle policy."""
    description: builtins.str
    """Description of the lifecycle policy. 0-1024 characters long."""
    state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType
    """Initial state of the lifecycle policy."""
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule]:
        """List of lifecycle rules."""

    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule] | None = ...,
        state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "registry_id", b"registry_id", "rules", b"rules", "state", b"state"]) -> None: ...

global___CreateLifecyclePolicyRequest = CreateLifecyclePolicyRequest

@typing.final
class CreateLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy that is being created."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___CreateLifecyclePolicyMetadata = CreateLifecyclePolicyMetadata

@typing.final
class UpdateLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to update."""
    name: builtins.str
    """Name of the lifecycle policy."""
    description: builtins.str
    """Description of the lifecycle policy. 0-1024 characters long."""
    state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType
    """State of the lifecycle policy."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the lifecycle policy are going to be updated."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule]:
        """List of lifecycle rules."""

    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        rules: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecycleRule] | None = ...,
        state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "policy_id", b"policy_id", "rules", b"rules", "state", b"state", "update_mask", b"update_mask"]) -> None: ...

global___UpdateLifecyclePolicyRequest = UpdateLifecyclePolicyRequest

@typing.final
class UpdateLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy that is being updated."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___UpdateLifecyclePolicyMetadata = UpdateLifecyclePolicyMetadata

@typing.final
class DeleteLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to delete."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___DeleteLifecyclePolicyRequest = DeleteLifecyclePolicyRequest

@typing.final
class DeleteLifecyclePolicyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy that is being deleted."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___DeleteLifecyclePolicyMetadata = DeleteLifecyclePolicyMetadata

@typing.final
class GetLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to return."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id"]) -> None: ...

global___GetLifecyclePolicyRequest = GetLifecyclePolicyRequest

@typing.final
class ListLifecyclePolicyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to list lifecycle policies in."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token. To get the next page of results, set page_token to the
    ListLifecyclePolicyResponse.next_page_token returned by a previous list request.
    """
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "registry_id", b"registry_id"]) -> None: ...

global___ListLifecyclePolicyRequest = ListLifecyclePolicyRequest

@typing.final
class ListLifecyclePolicyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests."""
    @property
    def policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicy]:
        """List of lifecycle policy resources."""

    def __init__(
        self,
        *,
        policies: collections.abc.Iterable[yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicy] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "policies", b"policies"]) -> None: ...

global___ListLifecyclePolicyResponse = ListLifecyclePolicyResponse

@typing.final
class ChangeLifecyclePolicyStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """ID of the lifecycle policy to change state."""
    state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType
    """Target state of the lifecycle policy."""
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        state: yandex.cloud.cloudregistry.v1.lifecycle_policy_pb2.LifecyclePolicyState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["policy_id", b"policy_id", "state", b"state"]) -> None: ...

global___ChangeLifecyclePolicyStateRequest = ChangeLifecyclePolicyStateRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.resourcemanager.v1.folder_pb2
import yandex.cloud.resourcemanager.v1.folder_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class FolderServiceStub:
    """A set of methods for managing Folder resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.GetFolderRequest,
        yandex.cloud.resourcemanager.v1.folder_pb2.Folder,
    ]
    """Returns the specified Folder resource.

    To get the list of available Folder resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse,
    ]
    """Retrieves the list of Folder resources in the specified cloud."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.CreateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a folder in the specified cloud."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.UpdateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified folder."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.DeleteFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified folder."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse,
    ]
    """Lists operations for the specified folder."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified folder.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified folder."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified folder."""

    ListAccessPolicyBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse,
    ]
    """
    Access policies

    Returns list of access policy bindings for the folder.
    """

    BindAccessPolicy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.BindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Binds the access policy template to the folder."""

    UnbindAccessPolicy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UnbindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Unbinds the access policy template from the folder."""

    UpdateAccessPolicyBindingParameters: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessPolicyBindingParametersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the access policy binding parameters for the folder."""

class FolderServiceAsyncStub:
    """A set of methods for managing Folder resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.GetFolderRequest,
        yandex.cloud.resourcemanager.v1.folder_pb2.Folder,
    ]
    """Returns the specified Folder resource.

    To get the list of available Folder resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse,
    ]
    """Retrieves the list of Folder resources in the specified cloud."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.CreateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a folder in the specified cloud."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.UpdateFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified folder."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.DeleteFolderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified folder."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsRequest,
        yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse,
    ]
    """Lists operations for the specified folder."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified folder.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified folder."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified folder."""

    ListAccessPolicyBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse,
    ]
    """
    Access policies

    Returns list of access policy bindings for the folder.
    """

    BindAccessPolicy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.BindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Binds the access policy template to the folder."""

    UnbindAccessPolicy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UnbindAccessPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Unbinds the access policy template from the folder."""

    UpdateAccessPolicyBindingParameters: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessPolicyBindingParametersRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the access policy binding parameters for the folder."""

class FolderServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Folder resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.GetFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.resourcemanager.v1.folder_pb2.Folder, collections.abc.Awaitable[yandex.cloud.resourcemanager.v1.folder_pb2.Folder]]:
        """Returns the specified Folder resource.

        To get the list of available Folder resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse, collections.abc.Awaitable[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFoldersResponse]]:
        """Retrieves the list of Folder resources in the specified cloud."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.CreateFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a folder in the specified cloud."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.UpdateFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified folder."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.DeleteFolderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified folder."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse, collections.abc.Awaitable[yandex.cloud.resourcemanager.v1.folder_service_pb2.ListFolderOperationsResponse]]:
        """Lists operations for the specified folder."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the specified folder.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified folder."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified folder."""

    @abc.abstractmethod
    def ListAccessPolicyBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessPolicyBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessPolicyBindingsResponse]]:
        """
        Access policies

        Returns list of access policy bindings for the folder.
        """

    @abc.abstractmethod
    def BindAccessPolicy(
        self,
        request: yandex.cloud.access.access_pb2.BindAccessPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Binds the access policy template to the folder."""

    @abc.abstractmethod
    def UnbindAccessPolicy(
        self,
        request: yandex.cloud.access.access_pb2.UnbindAccessPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Unbinds the access policy template from the folder."""

    @abc.abstractmethod
    def UpdateAccessPolicyBindingParameters(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessPolicyBindingParametersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the access policy binding parameters for the folder."""

def add_FolderServiceServicer_to_server(servicer: FolderServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PublicPrefixPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CIDR_FIELD_NUMBER: builtins.int
    MIN_AVAILABLE_PREFIX_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the public prefix pool."""
    cloud_id: builtins.str
    """ID of the cloud that the public prefix pool belongs to."""
    folder_id: builtins.str
    """ID of the folder that the public prefix pool belongs to."""
    name: builtins.str
    """Name of the public prefix pool."""
    description: builtins.str
    """Description of the public prefix pool."""
    cidr: builtins.str
    """CIDR block of the public prefix pool."""
    @property
    def min_available_prefix(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Minimal prefix that could be used for subnet creation

        Read only.
        """

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        cidr: builtins.str = ...,
        min_available_prefix: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "min_available_prefix", b"min_available_prefix"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cidr", b"cidr", "cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "min_available_prefix", b"min_available_prefix", "name", b"name"]) -> None: ...

global___PublicPrefixPool = PublicPrefixPool



import os
import time
import warnings
from datetime import datetime
from typing import Dict, Optional, Union

# noinspection PyUnresolvedReferences
# jwt package depends on cryptography
import cryptography  # noqa: F401; pylint: disable=unused-import
import jwt
import requests

from yandex.cloud.iam.v1.iam_token_service_pb2 import CreateIamTokenRequest

_MDS_ADDR = "169.254.169.254"
_MDS_URL = "http://{}/computeMetadata/v1/instance/service-accounts/default/token"
_MDS_HEADERS = {"Metadata-Flavor": "Google"}
_MDS_TIMEOUT = (1.0, 1.0)  # 1sec connect, 1sec read

YC_API_ENDPOINT = "api.cloud.yandex.net"


def set_up_yc_api_endpoint(endpoint: str) -> str:
    # pylint: disable-next=global-statement
    global YC_API_ENDPOINT
    YC_API_ENDPOINT = endpoint
    return YC_API_ENDPOINT


def __validate_service_account_key(sa_key: Optional[dict]) -> bool:
    if not isinstance(sa_key, dict):
        raise RuntimeError(f"Invalid Service Account Key: expecting dictionary, actually got {type(sa_key)}")

    obj_id = sa_key.get("id")
    sa_id = sa_key.get("service_account_id")
    private_key = sa_key.get("private_key")

    if not obj_id:
        raise RuntimeError("Invalid Service Account Key: missing key object id.")

    if not sa_id:
        raise RuntimeError("Invalid Service Account Key: missing service account id.")

    if not private_key:
        raise RuntimeError("Invalid Service Account Key: missing private key.")

    private_key_prefix = "-----BEGIN PRIVATE KEY-----"
    if not isinstance(private_key, str) or private_key_prefix not in private_key:
        error_message = (
            "Invalid Service Account Key: private key is in incorrect format."
            f"Should start with {private_key_prefix}.\n"
            "To obtain one you can use YC CLI: yc iam key create --output sa.json --service-account-id <id>"
        )
        raise RuntimeError(error_message)
    return True


class MetadataAuth:
    def __init__(self, metadata_addr: str):
        self.__metadata_addr = metadata_addr

    def url(self) -> str:
        return _MDS_URL.format(self.__metadata_addr)

    def get_token(self) -> str:
        r = requests.get(self.url(), headers=_MDS_HEADERS, timeout=_MDS_TIMEOUT)
        r.raise_for_status()
        response = r.json()
        return response["access_token"]


class TokenAuth:
    def __init__(self, token: str):
        self.__oauth_token = token

    def get_token_request(self) -> "CreateIamTokenRequest":
        return CreateIamTokenRequest(yandex_passport_oauth_token=self.__oauth_token)


class ServiceAccountAuth:
    __SECONDS_IN_HOUR = 60.0 * 60.0

    def __init__(self, sa_key: Dict[str, str], endpoint: Optional[str] = None):
        self.__sa_key = sa_key
        self._endpoint = endpoint if endpoint is not None else YC_API_ENDPOINT

    def get_token_request(self) -> "CreateIamTokenRequest":
        return CreateIamTokenRequest(jwt=self.__prepare_request(self._endpoint))

    def __prepare_request(self, endpoint: str) -> str:
        now = time.time()
        now_utc = datetime.utcfromtimestamp(now)
        exp_utc = datetime.utcfromtimestamp(now + self.__SECONDS_IN_HOUR)
        url = f"https://iam.{endpoint}/iam/v1/tokens"
        payload = {
            "iss": self.__sa_key["service_account_id"],
            "aud": url,
            "iat": now_utc,
            "exp": exp_utc,
        }

        headers = {
            "typ": "JWT",
            "alg": "PS256",
            "kid": self.__sa_key["id"],
        }

        return jwt.encode(payload, self.__sa_key["private_key"], algorithm="PS256", headers=headers)


class IamTokenAuth:
    def __init__(self, iam_token: str):
        self.__iam_token = iam_token

    def get_token(self) -> str:
        return self.__iam_token


def get_auth_token_requester(
    token: Optional[str] = None,
    service_account_key: Optional[dict] = None,
    iam_token: Optional[str] = None,
    metadata_addr: Optional[str] = None,
    endpoint: Optional[str] = None,
) -> Union["MetadataAuth", "TokenAuth", "IamTokenAuth", "ServiceAccountAuth"]:
    if endpoint is None:
        endpoint = YC_API_ENDPOINT
    auth_methods = [("token", token), ("service_account_key", service_account_key), ("iam_token", iam_token)]
    auth_methods = [(auth_type, value) for auth_type, value in auth_methods if value is not None]

    if len(auth_methods) == 0:
        metadata_addr = metadata_addr if metadata_addr is not None else os.environ.get("YC_METADATA_ADDR", _MDS_ADDR)
        return MetadataAuth(metadata_addr)

    if len(auth_methods) > 1:
        raise RuntimeError(f"Conflicting API credentials properties are set: {[auth[0] for auth in auth_methods]}.")

    if token is not None:
        warnings.warn(
            """The 'token' argument corresponds to OAuthToken credential provider, which is deprecated at Yandex Cloud.
            By the end of 2026 will be fully discontinued. Please consider to use another credetials provider.""",
            DeprecationWarning,
            stacklevel=2,
        )
        return TokenAuth(token=token)
    if iam_token is not None:
        return IamTokenAuth(iam_token)
    if service_account_key is not None and __validate_service_account_key(service_account_key):
        return ServiceAccountAuth(service_account_key, endpoint)

    raise RuntimeError("Unknown auth method")
